import os, platform, subprocess, sys

def main():
    system = platform.system().lower()
    arch   = platform.machine().lower()
    key    = f"{system}-{arch}"
    fn     = f"jsonschema-{key}.exe" if system=="windows" else f"jsonschema-{key}"
    path   = os.path.join(os.path.dirname(__file__), fn)
    if not os.path.exists(path):
        print(f"Unsupported platform: {key}", file=sys.stderr)
        sys.exit(1)
    subprocess.run([path]+sys.argv[1:], check=True)

if __name__=="__main__":
    main()



from setuptools import setup, find_packages

setup(
    name         = "sourcemeta_jsonschema",
    version      = "11.11.1",
    description  = "The CLI for working with JSON Schema. Covers formatting, linting, testing, and much more for both local development and CI/CD pipelines",
    author       = "Sourcemeta",
    author_email = "hello@sourcemeta.com",
    url          = "https://github.com/sourcemeta/jsonschema",
    license      = "AGPL-3.0",
    packages     = find_packages(),
    include_package_data = True,
    package_data = {
        "sourcemeta_jsonschema": ["*.exe", "jsonschema-*"]
    },
    python_requires = ">=3.7",
    entry_points = {
        "console_scripts": [
            "jsonschema = sourcemeta_jsonschema.__main__:main"
        ]
    }
)
